@@ -1,10 +1,14 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Mpltoolbox contributors (https://github.com/mpltoolbox)
+# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
 
 # flake8: noqa
 
+from .event import DummyEvent
+from .tool import Tool
 from .lines import Lines
 from .rectangles import Rectangles
 from .ellipses import Ellipses
 from .points import Points
 from .polygons import Polygons
+from .hspans import Hspans
+from .vspans import Vspans
